@@ -60,9 +60,9 @@ class FirestoreClient(BaseClient):
             LOG.error(f"Dict = {data}")
             raise DatabaseError(f"Document with id: {_id} already exists")
 
-        LOG.info("Insert Result: {}", result[1].id)
+        LOG.info(f"Insert Result: {result}")
 
-        return WriteResult(transform_results=[result[1].id])
+        return WriteResult(transform_results=[result])
 
     async def count(self, model: Type[DocumentDBModel], session: Any = None) -> int:
 
@@ -144,7 +144,7 @@ class FirestoreClient(BaseClient):
         result = await force_async(query_ref.stream)()
 
         for res in result:
-            LOG.debug("Find One Result: {}", res.to_dict())
+            LOG.debug(f"Find One Result: {res.to_dict()}")
             item = model(**res.to_dict())
             item.id = res.id
             return item
