@@ -10,3 +10,10 @@ class CamelModel(BaseModel):
     class Config:
         alias_generator = to_camel
         allow_population_by_field_name = True
+
+
+class FileDownloadRef(CamelModel):
+    name: str
+    url: str
+    extension: str
+    size: int
