@@ -74,7 +74,8 @@ class GitlabClient:
                 {"name": project_name, "namespace_id": settings.GITLAB_GROUP_ID}
             )
 
-        LOG.info(f"Created project: {project}")
+        LOG.info(f"Created CI Project: {project.id}")
+        LOG.debug(f"{project}")
 
         data = {
             "branch": "master",
@@ -84,7 +85,8 @@ class GitlabClient:
             ],
         }
         commit = await force_async(project.commits.create)(data)
-        LOG.info(f"Created commit: {commit}")
+        LOG.info(f"Created CI Commit: {commit.id}")
+        LOG.debug(f"{commit}")
 
         return project
 
@@ -151,7 +153,8 @@ class GitlabClient:
             ],
         }
         commit = await force_async(project.commits.create)(data)
-        LOG.info(f"Created CI Commit: {commit}")
+        LOG.info(f"Created CI Commit: {commit.id}")
+        LOG.debug(f"{commit}")
 
         return commit.id
 
