@@ -74,7 +74,7 @@ def clean_env():
     os.environ.pop("BUCKET_NAME", None)
     os.environ.pop("BUCKET_USER_FOLDER", None)
     os.environ.pop("DATABASE_TYPE", None)
-    os.environ.pop("GOOGLE_APPLICATION_CREDENTIALS", None)
+    # os.environ.pop("GOOGLE_APPLICATION_CREDENTIALS", None)
     os.environ.pop("ENABLE_FIREBASE", None)
     os.environ.pop("MINIO_ENDPOINT", None)
     os.environ.pop("MINIO_ACCESS_KEY", None)
